Translate Toolkit 3.4.0
***********************

*Released on 19 August 2021*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- Fluent
   
  - Initial support for Mozilla Fluent format

- Stringsdict

  - Initial support for Apple Stringsdict format

- JSON

  - Handle crash when can not detect encoding

- PO

  - Fail on syntactically invalid PO files


Contributors
============

This release was made possible by the following people:

Michal Čihař, Jack Grigg, Tim Gates, Lennard Sprong
